def get_default_profile_photo() -> dict:
    return {
        "id": "default",
        "key": "default",
        "filename": "default.png",
        "unique_filename": "default.png",
        "url": "https://cdn.inceptionforce.com/png/df/default.png",
        "content_type": "image/png",
        "extension": "png",
        "size": "100KB",
    }
